GOAL: We input the environmental variables into docker-compose.yml

Create app.js:
```
require('dotenv').config();

const test = process.env?.test || "";
console.log(`Hello, thanks for feeding env variables directly at the Dockerfile. I can read env variable "test" and its value is: ${test}`);
```

Create package.json:
```
{
  "dependencies": {
    "dotenv": "16.4.7"
  }
}
```

Dockerfile:
```
# Use the specific NodeJS base image (bundled in Debian)
FROM node:18

# Set the working directory in the container.
# All below commands will work from working directory.
WORKDIR /app

# Copy the package.json file to the container
COPY package.json .

# Install the NodeJS packages
RUN npm install

# Copy your application files (if any)
COPY . .

# Specify the command to run your application (optional, depends on your use case)
CMD ["node", "app.js"]
```

^ We shouldn't have to explain any of the above lines because you would've mastered them by this point in the challenge series.

.dockerignore:
```
.DS_Store
node_modules
package-lock.json
__pycache__
*.pyc
.env
```

docker-compose.yml:
```
version: "3.8"
services:
  env-dc:
    build:
      context: .
    environment:
      - test=456
```

Let's build the image and run it as a virtual container using one Docker Compose command:
```
docker compose up
```
^ Note we removed the "-d" detached/daemon/background mode because we want to see the output in the terminal.

Your output should look like:
```
Hello, thanks for feeding env variables directly at the Dockerfile. I can read env variable "test" and its value is: 456
```

When done, perform cleanup.